Class: Aws::ForecastService::Types::CreateWhatIfAnalysisRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-forecastservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#forecast_arn ⇒ String

The Amazon Resource Name (ARN) of the baseline forecast.

Returns:

  • (String)


1694
1695
1696
1697
1698
1699
1700
1701
# File 'lib/aws-sdk-forecastservice/types.rb', line 1694

class CreateWhatIfAnalysisRequest < Struct.new(
  :what_if_analysis_name,
  :forecast_arn,
  :time_series_selector,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

A list of tags to apply to the what if forecast.

Returns:



1694
1695
1696
1697
1698
1699
1700
1701
# File 'lib/aws-sdk-forecastservice/types.rb', line 1694

class CreateWhatIfAnalysisRequest < Struct.new(
  :what_if_analysis_name,
  :forecast_arn,
  :time_series_selector,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#time_series_selector ⇒ Types::TimeSeriesSelector

Defines the set of time series that are used in the what-if analysis with a TimeSeriesIdentifiers object. What-if analyses are performed only for the time series in this object.

The TimeSeriesIdentifiers object needs the following information:

  • DataSource

  • Format

  • Schema



1694
1695
1696
1697
1698
1699
1700
1701
# File 'lib/aws-sdk-forecastservice/types.rb', line 1694

class CreateWhatIfAnalysisRequest < Struct.new(
  :what_if_analysis_name,
  :forecast_arn,
  :time_series_selector,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#what_if_analysis_name ⇒ String

The name of the what-if analysis. Each name must be unique.

Returns:

  • (String)


1694
1695
1696
1697
1698
1699
1700
1701
# File 'lib/aws-sdk-forecastservice/types.rb', line 1694

class CreateWhatIfAnalysisRequest < Struct.new(
  :what_if_analysis_name,
  :forecast_arn,
  :time_series_selector,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end