Class: Aws::ForecastService::Types::DatasetSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-forecastservice/types.rb

Overview

Provides a summary of the dataset properties used in the ListDatasets operation. To get the complete set of properties, call the DescribeDataset operation, and provide the DatasetArn.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time ⇒ Time

When the dataset was created.

Returns:

  • (Time)


2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
# File 'lib/aws-sdk-forecastservice/types.rb', line 2067

class DatasetSummary < Struct.new(
  :dataset_arn,
  :dataset_name,
  :dataset_type,
  :domain,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_arn ⇒ String

The Amazon Resource Name (ARN) of the dataset.

Returns:

  • (String)


2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
# File 'lib/aws-sdk-forecastservice/types.rb', line 2067

class DatasetSummary < Struct.new(
  :dataset_arn,
  :dataset_name,
  :dataset_type,
  :domain,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_name ⇒ String

The name of the dataset.

Returns:

  • (String)


2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
# File 'lib/aws-sdk-forecastservice/types.rb', line 2067

class DatasetSummary < Struct.new(
  :dataset_arn,
  :dataset_name,
  :dataset_type,
  :domain,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_type ⇒ String

The dataset type.

Returns:

  • (String)


2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
# File 'lib/aws-sdk-forecastservice/types.rb', line 2067

class DatasetSummary < Struct.new(
  :dataset_arn,
  :dataset_name,
  :dataset_type,
  :domain,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#domain ⇒ String

The domain associated with the dataset.

Returns:

  • (String)


2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
# File 'lib/aws-sdk-forecastservice/types.rb', line 2067

class DatasetSummary < Struct.new(
  :dataset_arn,
  :dataset_name,
  :dataset_type,
  :domain,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_modification_time ⇒ Time

When you create a dataset, LastModificationTime is the same as CreationTime. While data is being imported to the dataset, LastModificationTime is the current time of the ListDatasets call. After a CreateDatasetImportJob operation has finished, LastModificationTime is when the import job completed or failed.

Returns:

  • (Time)


2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
# File 'lib/aws-sdk-forecastservice/types.rb', line 2067

class DatasetSummary < Struct.new(
  :dataset_arn,
  :dataset_name,
  :dataset_type,
  :domain,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end