Class: Aws::ForecastService::Types::DescribeExplainabilityResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-forecastservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time ⇒ Time

When the Explainability resource was created.

Returns:

  • (Time)


2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
2936
2937
2938
# File 'lib/aws-sdk-forecastservice/types.rb', line 2921

class DescribeExplainabilityResponse < Struct.new(
  :explainability_arn,
  :explainability_name,
  :resource_arn,
  :explainability_config,
  :enable_visualization,
  :data_source,
  :schema,
  :start_date_time,
  :end_date_time,
  :estimated_time_remaining_in_minutes,
  :message,
  :status,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#data_source ⇒ Types::DataSource

The source of your data, an Identity and Access Management (IAM) role that allows Amazon Forecast to access the data and, optionally, an Key Management Service (KMS) key.

Returns:



2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
2936
2937
2938
# File 'lib/aws-sdk-forecastservice/types.rb', line 2921

class DescribeExplainabilityResponse < Struct.new(
  :explainability_arn,
  :explainability_name,
  :resource_arn,
  :explainability_config,
  :enable_visualization,
  :data_source,
  :schema,
  :start_date_time,
  :end_date_time,
  :estimated_time_remaining_in_minutes,
  :message,
  :status,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#enable_visualization ⇒ Boolean

Whether the visualization was enabled for the Explainability resource.

Returns:

  • (Boolean)


2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
2936
2937
2938
# File 'lib/aws-sdk-forecastservice/types.rb', line 2921

class DescribeExplainabilityResponse < Struct.new(
  :explainability_arn,
  :explainability_name,
  :resource_arn,
  :explainability_config,
  :enable_visualization,
  :data_source,
  :schema,
  :start_date_time,
  :end_date_time,
  :estimated_time_remaining_in_minutes,
  :message,
  :status,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#end_date_time ⇒ String

If TimePointGranularity is set to SPECIFIC, the last time point in the Explainability.

Returns:

  • (String)


2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
2936
2937
2938
# File 'lib/aws-sdk-forecastservice/types.rb', line 2921

class DescribeExplainabilityResponse < Struct.new(
  :explainability_arn,
  :explainability_name,
  :resource_arn,
  :explainability_config,
  :enable_visualization,
  :data_source,
  :schema,
  :start_date_time,
  :end_date_time,
  :estimated_time_remaining_in_minutes,
  :message,
  :status,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#estimated_time_remaining_in_minutes ⇒ Integer

The estimated time remaining in minutes for the CreateExplainability job to complete.

Returns:

  • (Integer)


2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
2936
2937
2938
# File 'lib/aws-sdk-forecastservice/types.rb', line 2921

class DescribeExplainabilityResponse < Struct.new(
  :explainability_arn,
  :explainability_name,
  :resource_arn,
  :explainability_config,
  :enable_visualization,
  :data_source,
  :schema,
  :start_date_time,
  :end_date_time,
  :estimated_time_remaining_in_minutes,
  :message,
  :status,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#explainability_arn ⇒ String

The Amazon Resource Name (ARN) of the Explainability.

Returns:

  • (String)


2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
2936
2937
2938
# File 'lib/aws-sdk-forecastservice/types.rb', line 2921

class DescribeExplainabilityResponse < Struct.new(
  :explainability_arn,
  :explainability_name,
  :resource_arn,
  :explainability_config,
  :enable_visualization,
  :data_source,
  :schema,
  :start_date_time,
  :end_date_time,
  :estimated_time_remaining_in_minutes,
  :message,
  :status,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#explainability_config ⇒ Types::ExplainabilityConfig

The configuration settings that define the granularity of time series and time points for the Explainability.



2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
2936
2937
2938
# File 'lib/aws-sdk-forecastservice/types.rb', line 2921

class DescribeExplainabilityResponse < Struct.new(
  :explainability_arn,
  :explainability_name,
  :resource_arn,
  :explainability_config,
  :enable_visualization,
  :data_source,
  :schema,
  :start_date_time,
  :end_date_time,
  :estimated_time_remaining_in_minutes,
  :message,
  :status,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#explainability_name ⇒ String

The name of the Explainability.

Returns:

  • (String)


2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
2936
2937
2938
# File 'lib/aws-sdk-forecastservice/types.rb', line 2921

class DescribeExplainabilityResponse < Struct.new(
  :explainability_arn,
  :explainability_name,
  :resource_arn,
  :explainability_config,
  :enable_visualization,
  :data_source,
  :schema,
  :start_date_time,
  :end_date_time,
  :estimated_time_remaining_in_minutes,
  :message,
  :status,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_modification_time ⇒ Time

The last time the resource was modified. The timestamp depends on the status of the job:

  • CREATE_PENDING - The CreationTime.

  • CREATE_IN_PROGRESS - The current timestamp.

  • CREATE_STOPPING - The current timestamp.

  • CREATE_STOPPED - When the job stopped.

  • ACTIVE or CREATE_FAILED - When the job finished or failed.

Returns:

  • (Time)


2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
2936
2937
2938
# File 'lib/aws-sdk-forecastservice/types.rb', line 2921

class DescribeExplainabilityResponse < Struct.new(
  :explainability_arn,
  :explainability_name,
  :resource_arn,
  :explainability_config,
  :enable_visualization,
  :data_source,
  :schema,
  :start_date_time,
  :end_date_time,
  :estimated_time_remaining_in_minutes,
  :message,
  :status,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#message ⇒ String

If an error occurred, a message about the error.

Returns:

  • (String)


2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
2936
2937
2938
# File 'lib/aws-sdk-forecastservice/types.rb', line 2921

class DescribeExplainabilityResponse < Struct.new(
  :explainability_arn,
  :explainability_name,
  :resource_arn,
  :explainability_config,
  :enable_visualization,
  :data_source,
  :schema,
  :start_date_time,
  :end_date_time,
  :estimated_time_remaining_in_minutes,
  :message,
  :status,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arn ⇒ String

The Amazon Resource Name (ARN) of the Predictor or Forecast used to create the Explainability resource.

Returns:

  • (String)


2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
2936
2937
2938
# File 'lib/aws-sdk-forecastservice/types.rb', line 2921

class DescribeExplainabilityResponse < Struct.new(
  :explainability_arn,
  :explainability_name,
  :resource_arn,
  :explainability_config,
  :enable_visualization,
  :data_source,
  :schema,
  :start_date_time,
  :end_date_time,
  :estimated_time_remaining_in_minutes,
  :message,
  :status,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#schema ⇒ Types::Schema

Defines the fields of a dataset.

Returns:



2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
2936
2937
2938
# File 'lib/aws-sdk-forecastservice/types.rb', line 2921

class DescribeExplainabilityResponse < Struct.new(
  :explainability_arn,
  :explainability_name,
  :resource_arn,
  :explainability_config,
  :enable_visualization,
  :data_source,
  :schema,
  :start_date_time,
  :end_date_time,
  :estimated_time_remaining_in_minutes,
  :message,
  :status,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#start_date_time ⇒ String

If TimePointGranularity is set to SPECIFIC, the first time point in the Explainability.

Returns:

  • (String)


2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
2936
2937
2938
# File 'lib/aws-sdk-forecastservice/types.rb', line 2921

class DescribeExplainabilityResponse < Struct.new(
  :explainability_arn,
  :explainability_name,
  :resource_arn,
  :explainability_config,
  :enable_visualization,
  :data_source,
  :schema,
  :start_date_time,
  :end_date_time,
  :estimated_time_remaining_in_minutes,
  :message,
  :status,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the Explainability resource. States include:

  • ACTIVE

  • CREATE_PENDING, CREATE_IN_PROGRESS, CREATE_FAILED

  • CREATE_STOPPING, CREATE_STOPPED

  • DELETE_PENDING, DELETE_IN_PROGRESS, DELETE_FAILED

Returns:

  • (String)


2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
2936
2937
2938
# File 'lib/aws-sdk-forecastservice/types.rb', line 2921

class DescribeExplainabilityResponse < Struct.new(
  :explainability_arn,
  :explainability_name,
  :resource_arn,
  :explainability_config,
  :enable_visualization,
  :data_source,
  :schema,
  :start_date_time,
  :end_date_time,
  :estimated_time_remaining_in_minutes,
  :message,
  :status,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end