Class: Aws::ForecastService::Types::DescribeWhatIfAnalysisResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-forecastservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time ⇒ Time

When the what-if analysis was created.

Returns:

  • (Time)


3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
3581
3582
# File 'lib/aws-sdk-forecastservice/types.rb', line 3570

class DescribeWhatIfAnalysisResponse < Struct.new(
  :what_if_analysis_name,
  :what_if_analysis_arn,
  :forecast_arn,
  :estimated_time_remaining_in_minutes,
  :status,
  :message,
  :creation_time,
  :last_modification_time,
  :time_series_selector)
  SENSITIVE = []
  include Aws::Structure
end

#estimated_time_remaining_in_minutes ⇒ Integer

The approximate time remaining to complete the what-if analysis, in minutes.

Returns:

  • (Integer)


3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
3581
3582
# File 'lib/aws-sdk-forecastservice/types.rb', line 3570

class DescribeWhatIfAnalysisResponse < Struct.new(
  :what_if_analysis_name,
  :what_if_analysis_arn,
  :forecast_arn,
  :estimated_time_remaining_in_minutes,
  :status,
  :message,
  :creation_time,
  :last_modification_time,
  :time_series_selector)
  SENSITIVE = []
  include Aws::Structure
end

#forecast_arn ⇒ String

The Amazon Resource Name (ARN) of the what-if forecast.

Returns:

  • (String)


3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
3581
3582
# File 'lib/aws-sdk-forecastservice/types.rb', line 3570

class DescribeWhatIfAnalysisResponse < Struct.new(
  :what_if_analysis_name,
  :what_if_analysis_arn,
  :forecast_arn,
  :estimated_time_remaining_in_minutes,
  :status,
  :message,
  :creation_time,
  :last_modification_time,
  :time_series_selector)
  SENSITIVE = []
  include Aws::Structure
end

#last_modification_time ⇒ Time

The last time the resource was modified. The timestamp depends on the status of the job:

  • CREATE_PENDING - The CreationTime.

  • CREATE_IN_PROGRESS - The current timestamp.

  • CREATE_STOPPING - The current timestamp.

  • CREATE_STOPPED - When the job stopped.

  • ACTIVE or CREATE_FAILED - When the job finished or failed.

Returns:

  • (Time)


3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
3581
3582
# File 'lib/aws-sdk-forecastservice/types.rb', line 3570

class DescribeWhatIfAnalysisResponse < Struct.new(
  :what_if_analysis_name,
  :what_if_analysis_arn,
  :forecast_arn,
  :estimated_time_remaining_in_minutes,
  :status,
  :message,
  :creation_time,
  :last_modification_time,
  :time_series_selector)
  SENSITIVE = []
  include Aws::Structure
end

#message ⇒ String

If an error occurred, an informational message about the error.

Returns:

  • (String)


3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
3581
3582
# File 'lib/aws-sdk-forecastservice/types.rb', line 3570

class DescribeWhatIfAnalysisResponse < Struct.new(
  :what_if_analysis_name,
  :what_if_analysis_arn,
  :forecast_arn,
  :estimated_time_remaining_in_minutes,
  :status,
  :message,
  :creation_time,
  :last_modification_time,
  :time_series_selector)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the what-if analysis. States include:

  • ACTIVE

  • CREATE_PENDING, CREATE_IN_PROGRESS, CREATE_FAILED

  • CREATE_STOPPING, CREATE_STOPPED

  • DELETE_PENDING, DELETE_IN_PROGRESS, DELETE_FAILED

The Status of the what-if analysis must be ACTIVE before you can access the analysis.

Returns:

  • (String)


3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
3581
3582
# File 'lib/aws-sdk-forecastservice/types.rb', line 3570

class DescribeWhatIfAnalysisResponse < Struct.new(
  :what_if_analysis_name,
  :what_if_analysis_arn,
  :forecast_arn,
  :estimated_time_remaining_in_minutes,
  :status,
  :message,
  :creation_time,
  :last_modification_time,
  :time_series_selector)
  SENSITIVE = []
  include Aws::Structure
end

#time_series_selector ⇒ Types::TimeSeriesSelector

Defines the set of time series that are used to create the forecasts in a TimeSeriesIdentifiers object.

The TimeSeriesIdentifiers object needs the following information:

  • DataSource

  • Format

  • Schema



3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
3581
3582
# File 'lib/aws-sdk-forecastservice/types.rb', line 3570

class DescribeWhatIfAnalysisResponse < Struct.new(
  :what_if_analysis_name,
  :what_if_analysis_arn,
  :forecast_arn,
  :estimated_time_remaining_in_minutes,
  :status,
  :message,
  :creation_time,
  :last_modification_time,
  :time_series_selector)
  SENSITIVE = []
  include Aws::Structure
end

#what_if_analysis_arn ⇒ String

The Amazon Resource Name (ARN) of the what-if analysis.

Returns:

  • (String)


3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
3581
3582
# File 'lib/aws-sdk-forecastservice/types.rb', line 3570

class DescribeWhatIfAnalysisResponse < Struct.new(
  :what_if_analysis_name,
  :what_if_analysis_arn,
  :forecast_arn,
  :estimated_time_remaining_in_minutes,
  :status,
  :message,
  :creation_time,
  :last_modification_time,
  :time_series_selector)
  SENSITIVE = []
  include Aws::Structure
end

#what_if_analysis_name ⇒ String

The name of the what-if analysis.

Returns:

  • (String)


3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
3581
3582
# File 'lib/aws-sdk-forecastservice/types.rb', line 3570

class DescribeWhatIfAnalysisResponse < Struct.new(
  :what_if_analysis_name,
  :what_if_analysis_arn,
  :forecast_arn,
  :estimated_time_remaining_in_minutes,
  :status,
  :message,
  :creation_time,
  :last_modification_time,
  :time_series_selector)
  SENSITIVE = []
  include Aws::Structure
end