Class: Aws::ForecastService::Types::Statistics

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-forecastservice/types.rb

Overview

Provides statistics for each data field imported into to an Amazon Forecast dataset with the CreateDatasetImportJob operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#avg ⇒ Float

For a numeric field, the average value in the field.

Returns:

  • (Float)


6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-forecastservice/types.rb', line 6330

class Statistics < Struct.new(
  :count,
  :count_distinct,
  :count_null,
  :count_nan,
  :min,
  :max,
  :avg,
  :stddev,
  :count_long,
  :count_distinct_long,
  :count_null_long,
  :count_nan_long)
  SENSITIVE = []
  include Aws::Structure
end

#count ⇒ Integer

The number of values in the field. If the response value is -1, refer to CountLong.

Returns:

  • (Integer)


6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-forecastservice/types.rb', line 6330

class Statistics < Struct.new(
  :count,
  :count_distinct,
  :count_null,
  :count_nan,
  :min,
  :max,
  :avg,
  :stddev,
  :count_long,
  :count_distinct_long,
  :count_null_long,
  :count_nan_long)
  SENSITIVE = []
  include Aws::Structure
end

#count_distinct ⇒ Integer

The number of distinct values in the field. If the response value is -1, refer to CountDistinctLong.

Returns:

  • (Integer)


6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-forecastservice/types.rb', line 6330

class Statistics < Struct.new(
  :count,
  :count_distinct,
  :count_null,
  :count_nan,
  :min,
  :max,
  :avg,
  :stddev,
  :count_long,
  :count_distinct_long,
  :count_null_long,
  :count_nan_long)
  SENSITIVE = []
  include Aws::Structure
end

#count_distinct_long ⇒ Integer

The number of distinct values in the field. CountDistinctLong is used instead of CountDistinct if the value is greater than 2,147,483,647.

Returns:

  • (Integer)


6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-forecastservice/types.rb', line 6330

class Statistics < Struct.new(
  :count,
  :count_distinct,
  :count_null,
  :count_nan,
  :min,
  :max,
  :avg,
  :stddev,
  :count_long,
  :count_distinct_long,
  :count_null_long,
  :count_nan_long)
  SENSITIVE = []
  include Aws::Structure
end

#count_long ⇒ Integer

The number of values in the field. CountLong is used instead of Count if the value is greater than 2,147,483,647.

Returns:

  • (Integer)


6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-forecastservice/types.rb', line 6330

class Statistics < Struct.new(
  :count,
  :count_distinct,
  :count_null,
  :count_nan,
  :min,
  :max,
  :avg,
  :stddev,
  :count_long,
  :count_distinct_long,
  :count_null_long,
  :count_nan_long)
  SENSITIVE = []
  include Aws::Structure
end

#count_nan ⇒ Integer

The number of NAN (not a number) values in the field. If the response value is -1, refer to CountNanLong.

Returns:

  • (Integer)


6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-forecastservice/types.rb', line 6330

class Statistics < Struct.new(
  :count,
  :count_distinct,
  :count_null,
  :count_nan,
  :min,
  :max,
  :avg,
  :stddev,
  :count_long,
  :count_distinct_long,
  :count_null_long,
  :count_nan_long)
  SENSITIVE = []
  include Aws::Structure
end

#count_nan_long ⇒ Integer

The number of NAN (not a number) values in the field. CountNanLong is used instead of CountNan if the value is greater than 2,147,483,647.

Returns:

  • (Integer)


6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-forecastservice/types.rb', line 6330

class Statistics < Struct.new(
  :count,
  :count_distinct,
  :count_null,
  :count_nan,
  :min,
  :max,
  :avg,
  :stddev,
  :count_long,
  :count_distinct_long,
  :count_null_long,
  :count_nan_long)
  SENSITIVE = []
  include Aws::Structure
end

#count_null ⇒ Integer

The number of null values in the field. If the response value is -1, refer to CountNullLong.

Returns:

  • (Integer)


6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-forecastservice/types.rb', line 6330

class Statistics < Struct.new(
  :count,
  :count_distinct,
  :count_null,
  :count_nan,
  :min,
  :max,
  :avg,
  :stddev,
  :count_long,
  :count_distinct_long,
  :count_null_long,
  :count_nan_long)
  SENSITIVE = []
  include Aws::Structure
end

#count_null_long ⇒ Integer

The number of null values in the field. CountNullLong is used instead of CountNull if the value is greater than 2,147,483,647.

Returns:

  • (Integer)


6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-forecastservice/types.rb', line 6330

class Statistics < Struct.new(
  :count,
  :count_distinct,
  :count_null,
  :count_nan,
  :min,
  :max,
  :avg,
  :stddev,
  :count_long,
  :count_distinct_long,
  :count_null_long,
  :count_nan_long)
  SENSITIVE = []
  include Aws::Structure
end

#max ⇒ String

For a numeric field, the maximum value in the field.

Returns:

  • (String)


6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-forecastservice/types.rb', line 6330

class Statistics < Struct.new(
  :count,
  :count_distinct,
  :count_null,
  :count_nan,
  :min,
  :max,
  :avg,
  :stddev,
  :count_long,
  :count_distinct_long,
  :count_null_long,
  :count_nan_long)
  SENSITIVE = []
  include Aws::Structure
end

#min ⇒ String

For a numeric field, the minimum value in the field.

Returns:

  • (String)


6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-forecastservice/types.rb', line 6330

class Statistics < Struct.new(
  :count,
  :count_distinct,
  :count_null,
  :count_nan,
  :min,
  :max,
  :avg,
  :stddev,
  :count_long,
  :count_distinct_long,
  :count_null_long,
  :count_nan_long)
  SENSITIVE = []
  include Aws::Structure
end

#stddev ⇒ Float

For a numeric field, the standard deviation.

Returns:

  • (Float)


6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-forecastservice/types.rb', line 6330

class Statistics < Struct.new(
  :count,
  :count_distinct,
  :count_null,
  :count_nan,
  :min,
  :max,
  :avg,
  :stddev,
  :count_long,
  :count_distinct_long,
  :count_null_long,
  :count_nan_long)
  SENSITIVE = []
  include Aws::Structure
end