Class: Aws::ForecastService::Types::WhatIfAnalysisSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-forecastservice/types.rb

Overview

Provides a summary of the what-if analysis properties used in the ListWhatIfAnalyses operation. To get the complete set of properties, call the DescribeWhatIfAnalysis operation, and provide the WhatIfAnalysisArn that is listed in the summary.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time ⇒ Time

When the what-if analysis was created.

Returns:

  • (Time)


7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
# File 'lib/aws-sdk-forecastservice/types.rb', line 7013

class WhatIfAnalysisSummary < Struct.new(
  :what_if_analysis_arn,
  :what_if_analysis_name,
  :forecast_arn,
  :status,
  :message,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#forecast_arn ⇒ String

The Amazon Resource Name (ARN) of the baseline forecast that is being used in this what-if analysis.

Returns:

  • (String)


7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
# File 'lib/aws-sdk-forecastservice/types.rb', line 7013

class WhatIfAnalysisSummary < Struct.new(
  :what_if_analysis_arn,
  :what_if_analysis_name,
  :forecast_arn,
  :status,
  :message,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_modification_time ⇒ Time

The last time the resource was modified. The timestamp depends on the status of the job:

  • CREATE_PENDING - The CreationTime.

  • CREATE_IN_PROGRESS - The current timestamp.

  • CREATE_STOPPING - The current timestamp.

  • CREATE_STOPPED - When the job stopped.

  • ACTIVE or CREATE_FAILED - When the job finished or failed.

Returns:

  • (Time)


7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
# File 'lib/aws-sdk-forecastservice/types.rb', line 7013

class WhatIfAnalysisSummary < Struct.new(
  :what_if_analysis_arn,
  :what_if_analysis_name,
  :forecast_arn,
  :status,
  :message,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#message ⇒ String

If an error occurred, an informational message about the error.

Returns:

  • (String)


7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
# File 'lib/aws-sdk-forecastservice/types.rb', line 7013

class WhatIfAnalysisSummary < Struct.new(
  :what_if_analysis_arn,
  :what_if_analysis_name,
  :forecast_arn,
  :status,
  :message,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the what-if analysis. States include:

  • ACTIVE

  • CREATE_PENDING, CREATE_IN_PROGRESS, CREATE_FAILED

  • CREATE_STOPPING, CREATE_STOPPED

  • DELETE_PENDING, DELETE_IN_PROGRESS, DELETE_FAILED

The Status of the what-if analysis must be ACTIVE before you can access the analysis.

Returns:

  • (String)


7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
# File 'lib/aws-sdk-forecastservice/types.rb', line 7013

class WhatIfAnalysisSummary < Struct.new(
  :what_if_analysis_arn,
  :what_if_analysis_name,
  :forecast_arn,
  :status,
  :message,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#what_if_analysis_arn ⇒ String

The Amazon Resource Name (ARN) of the what-if analysis.

Returns:

  • (String)


7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
# File 'lib/aws-sdk-forecastservice/types.rb', line 7013

class WhatIfAnalysisSummary < Struct.new(
  :what_if_analysis_arn,
  :what_if_analysis_name,
  :forecast_arn,
  :status,
  :message,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#what_if_analysis_name ⇒ String

The name of the what-if analysis.

Returns:

  • (String)


7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
# File 'lib/aws-sdk-forecastservice/types.rb', line 7013

class WhatIfAnalysisSummary < Struct.new(
  :what_if_analysis_arn,
  :what_if_analysis_name,
  :forecast_arn,
  :status,
  :message,
  :creation_time,
  :last_modification_time)
  SENSITIVE = []
  include Aws::Structure
end